@@ -39,6 +39,17 @@
 import sys
 from PyQt4 import QtGui, QtCore
 
+class AppWindow(QtGui.QMainWindow):
+        def __init__(self, parent = None):
+                QtGui.QMainWindow.__init__(self,parent)
+                self.close_listeners = []
+        def add_close_listener(self, l):
+                self.close_listeners.append(l)
+        def closeEvent(self, event):
+                for l in self.close_listeners:
+                        l.closeEvent(event)
+
+
 class InitDialog(QtGui.QDialog):
 	def __init__(self, parent=None):
 		QtGui.QDialog.__init__(self, parent)
@@ -67,7 +78,7 @@ class InitDialog(QtGui.QDialog):
 		del self.pixmap
 
 app = QtGui.QApplication(sys.argv)
-appwindow = QtGui.QMainWindow()
+appwindow = AppWindow()
 appwindow.setWindowTitle("BarrioSquare")
 initDialog = InitDialog(appwindow)
 initDialog.show()
